@@ -21,13 +21,15 @@ class ProviderSwitchHandler(object):
         self.allowed_providers = kwargs.get('allowed_providers', None)
         self.is_pagination = kwargs.get('is_pagination', False)
         self.num_of_pages = kwargs.get('num_of_pages', 1)
+        self.retry_when_not_found = kwargs.get('retry_when_not_found', False)
         self.providers = []
         self.current_provider = None
         self._prepare()
 
     def _prepare(self) -> None:
         providers = ProviderCollection(
-            driver_type='ssm', social_type=self.social_type, service_name=self.service_name).get_providers()
+            driver_type='ssm', social_type=self.social_type, service_name=self.service_name,
+            retry_when_not_found=self.retry_when_not_found).get_providers()
         if self.allowed_providers is not None:
             providers = [provider for provider in providers if provider.name in self.allowed_providers]
 
